#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Script to convert channel elevation data from the multiple .npy binaries
exported from the BlockLab model. This script does this for three user-
specified nodes.

Authors: Charlie Shobe and Rachel Glade, University of Colorado

Software: Python 2.7, Numpy

Note that the raw model channel elevation output consists of many .npy
binaries, and is therefore not included in this FigShare repository. The raw
model channel elevation output may be created by running the BlockLab model.
"""
#import
from __future__ import division
import numpy as np

#choose channel nodes to plot
lower_node = 1
middle_node = 60
upper_node = 120

#time indices corresponding to the .npy boinaries that will be imported
time_indices = np.arange(10000, 500000 + 10000, 10000)

#import data for first chosen node, re-export as singly .npy binary
loop_iter = 0
data = np.zeros((500000, 1))
for i in range(len(time_indices)):
    temp = np.load('revisions_point1_fixed_cover_fracs' + str(time_indices[i]) + '.npy')
    print(loop_iter)
    if loop_iter == 0:
        data[0:int(time_indices[i] / 2), 0] = temp[:,lower_node]
    else:
        data[int(time_indices[i-1] / 2):int(time_indices[i] / 2), 0] = temp[:,lower_node]
    loop_iter += 1
    
np.save('channel_cover_timeseries_lower_node.npy', data)

#import data for second chosen node, re-export as singly .npy binary
loop_iter = 0
data = np.zeros((250000, 1))
for i in range(len(time_indices)):
    temp = np.load('revisions_point1_fixed_cover_fracs' + str(time_indices[i]) + '.npy')
    print(loop_iter)
    if loop_iter == 0:
        data[0:int(time_indices[i] / 2), 0] = temp[:,middle_node]
    else:
        data[int(time_indices[i-1] / 2):int(time_indices[i] / 2), 0] = temp[:,middle_node]
    loop_iter += 1
    
np.save('channel_cover_timeseries_middle_node.npy', data)

#import data for third chosen node, re-export as singly .npy binary
loop_iter = 0
data = np.zeros((250000, 1)) 
for i in range(len(time_indices)):
    temp = np.load('revisions_point1_fixed_cover_fracs' + str(time_indices[i]) + '.npy')
    print(loop_iter)
    if loop_iter == 0:
        data[0:int(time_indices[i] / 2), 0] = temp[:,upper_node]
    else:
        data[int(time_indices[i-1] / 2):int(time_indices[i] / 2), 0] = temp[:,upper_node]
    loop_iter += 1
    
np.save('channel_cover_timeseries_upper_node.npy', data)
